@@ -151,10 +151,11 @@ def opendatafiles(tags=["bearing", "mats", "sgear", "shaft", "vbelt"], makezip=F
     """
     x = []
     import os
+    from melib.xt import ff2p
     pt = os.path.dirname(os.path.realpath(__file__))
     for s in tags:
         #        datafilename=DATAFOLDER+"\\"+"%s.xlsx"%s
-        datafilename=pt+"\\data\\%s.xlsx"%s
+        datafilename=pt+"/data/%s.xlsx"%s   # CHANGE 210812
         x.append(Xcel(datafilename))
         if makezip:
             mdxziplist([datafilename])
