@@ -12,7 +12,7 @@ from pylatex import Document, PageStyle, Head, LineBreak, simple_page_number,\
 Foot, MiniPage, LargeText, MediumText, Section, Subsection, Math, Alignat
 #, , , Tabular, , TikZ, Axis, \
 #     Plot, Figure, Matrix, , Quantity, , , \
-#     
+#
 # import matplotlib.image as mpimg
 import math
 import numpy as np
@@ -38,6 +38,8 @@ def iswindows(q):
 
 
 def ff2p(foldername, filename):
+    if foldername=="":
+        return filename
     if WINDOWS:
         return foldername+"\\"+filename
     else:
@@ -53,7 +55,7 @@ def mdzip(zipfile, listfile):
         listfile : The text file containing the file names to be archived (optional)
 
     For example,
-        mdzip("L10") -- Will archive the list in "L10_zip.txt" into "L10.zip" 
+        mdzip("L10") -- Will archive the list in "L10_zip.txt" into "L10.zip"
         mdzip("xxxx", "zzzz.txt") -- Will archive the list in "zzzz.txt" into "xxxx.zip"
     """
 
@@ -111,7 +113,7 @@ def mdxzipopen(notebook, libfiles):
     """
 
     global FZIP, ZIPFILES
-    FZIP = open(NOTEBOOK+"_zip.txt", "w")
+    FZIP = open(notebook+"_zip.txt", "w")
     ZIPFILES = []
     filelist = libfiles+[notebook+".ipynb", notebook+".html"]
     if os.path.exists("common.py"):
@@ -212,25 +214,25 @@ def openplot(figno, aspect=[]):
         `figno` : Figure numbers
 
         `aspect` : Aspect ratio, e.g. 0.5 for a rectangle width=2*height
-        
-        
+
+
     Returns (f1, ax)
-    
-        f1 = Pointer to the figure (can be used to save the figure, e.g. f1.savefig("myfigure.png") 
-        
+
+        f1 = Pointer to the figure (can be used to save the figure, e.g. f1.savefig("myfigure.png")
+
         ax = Pointer to the plot axes (use this to plot, e.g. ax.plot((x, y, "r", label="Y")))
 
     **Example**
-        
+
         >>> x=np.arange(0,10,0.01)
         >>> y=np.sin(x)
         >>> (f1,ax)=openplot(1,0.5)
         >>> ax.plot(x,y,"m",label="sine")
         >>> plotanno(ax,xlabel="X variable", ylabel="sin(x)", xlim=[1,9], ylim=[0, 1.0], grid="on", legendloc="upper right", title="Example - y=sin(x)")
-        
+
     """
-    
-    
+
+
     plt.close(1)
 #    f1=plt.figure()
     if aspect != []:
@@ -251,23 +253,23 @@ def openplot(figno, aspect=[]):
 
 def plotanno(ax, xlabel="", ylabel="", xlim=[], ylim=[], grid="on",
              legendloc="", title=""):
-    """ 
+    """
         For the matplotlib figure axis pointer ``ax``:
             Add axis labels (``xlabel`` and ``ylabel`` )
             Axis limits, e.g. ``xlim`` (=``[xmin, xmax]`` )
             Location for the legend , eg "upper right"
             Turn the grid lines on and off
             and a figure title
-            
+
         **Example**
-        
+
         >>> x=np.arange(0,10,0.01)
         >>> y=np.sin(x)
         >>> (f1,ax)=openplot(1,0.5)
         >>> ax.plot(x,y,"m",label="sine")
         >>> plotanno(ax,xlabel="X variable", ylabel="sin(x)", xlim=[1,9], ylim=[0, 1.0], grid="on", legendloc="upper right", title="Example - y=sin(x)")
 
-            
+
     """
     if ylim != []:
         ax.set_ylim(ylim)
@@ -303,32 +305,32 @@ def saveplot(fig, folder, filename):
 
 
 def imgplot(X, Y, XXYY, cs='b-', imgfile="", ax=[], xticks=[], yticks=[]):
-    """ 
+    """
         This function is used to superimpose my curve on a chart image from
         a reference.  The image should be the box only.
 
         ``X`` , ``Y``   The data to be plotted (the same units as on the chart image)
-        
-        ``XXYY``        The axis limits [[xmin, xmax], [ymin, ymax]] (from the reference image)
-        
-        ``cs``          Plot line descriptor, e.g. ``"b--"``
-        
-        ``imgfile``     The name of the output, e.g. ``r"pics\Meshram_Fig6b.png"``
-        
-        ``ax``          This should not be included at first call.  It is used to add curves later.
-        
-        ``xticks``      x-axis tick positions you want to see, e.g. ["4000", "midpoint", "26000"]
-        
-        ``yticks``      y-axis tick positions, e.g. ["ten", "forty", "seventy", "hundred"]
-        
 
-        The function returns ``(figno, ax)``. 
+        ``XXYY``        The axis limits [[xmin, xmax], [ymin, ymax]] (from the reference image)
+
+        ``cs``          Plot line descriptor, e.g. ``"b--"``
+
+        ``imgfile``     The name of the output, e.g. ``r"pics\Meshram_Fig6b.png"``
+
+        ``ax``          This should not be included at first call.  It is used to add curves later.
+
+        ``xticks``      x-axis tick positions you want to see, e.g. ["4000", "midpoint", "26000"]
+
+        ``yticks``      y-axis tick positions, e.g. ["ten", "forty", "seventy", "hundred"]
+
+
+        The function returns ``(figno, ax)``.
         The ``ax`` can be used to add more y(x) curves:
 
             e.g. imgplot(X2, Y2, XXYY, "r--", ax=ax)
-            
+
             The ``XXYY`` in the second call should be the same as in the first
-            
+
             The ``ax`` in the second call is the same 'ax' returned by the first call
 
         The ``figno`` can be used by the calling figure to save or to clear the figure
@@ -344,13 +346,13 @@ def imgplot(X, Y, XXYY, cs='b-', imgfile="", ax=[], xticks=[], yticks=[]):
         >>> plt.show()
 
     This example draws lines on the following reference chart:
-        
+
         .. image::  ../../assets/ashby_strength_density_chart.png
-        
+
     To create the following plot:
-        
+
         .. image:: ../../assets/imgplot.png
-    
+
     """
     def ptransform(XY, XXYY, xxyy):
         X1 = XXYY[0][0]
@@ -426,35 +428,35 @@ def eqnumber(s):
     return EQNUMS[s]
 
 class mdx:
-    """ 
+    """
         ``mdx`` is a pointer to a markdown file.  I use it in creating lecture
         notes.  A typical notebook have an iniialisation cell and then several
-        chapter cells.  
-        
-        The structures for these cells are given below.  Create a notebook 
-        named "XXXX.ipynb" and copy and paste the following code segments 
-        into that notebook as separate cells to create an example notebook 
+        chapter cells.
+
+        The structures for these cells are given below.  Create a notebook
+        named "XXXX.ipynb" and copy and paste the following code segments
+        into that notebook as separate cells to create an example notebook
         generated using the ``mdx`` class.
-        
+
         **Why should you use `` mdx `` ?**
-        
-        I found it clumsy to create markdown files with interactive live 
+
+        I found it clumsy to create markdown files with interactive live
         python code snippets in it when using standard markdown only.
-        
-        Using the class ``mdx``, all cells in the notebook 
+
+        Using the class ``mdx``, all cells in the notebook
         can be code cells and the whole notebook can run as a single program.
-        
-        The cell contents are created by using the ``mdx.write()`` method.  There 
-        are special codes starting with ``:::`` that can indicate headers, equations, 
-        insert images, and many other things.  See the write-up for the ``write`` 
+
+        The cell contents are created by using the ``mdx.write()`` method.  There
+        are special codes starting with ``:::`` that can indicate headers, equations,
+        insert images, and many other things.  See the write-up for the ``write``
         method.
-        
+
         **Initialisation Cell**
-        
-        This will be the first cell in the ``ipynb`` file and it will have the 
+
+        This will be the first cell in the ``ipynb`` file and it will have the
         following structure.  This is initialisation for a notebook with three chapter
         cells and one reference cell at the end.
-            
+
         .. code-block:: python
 
             import math
@@ -493,15 +495,15 @@ class mdx:
             md(MD.out())  # End of the initiation segment
 
         The following is what you need to generate an HTML page from this notebook.
-        
+
         ::
-            
+
             jupyter nbconvert XXXX.ipynb --no-input --to html
-            
-        
+
+
         **Chapter 1**
-        
-        This is the first chapter in the notebook following the initial cell. 
+
+        This is the first chapter in the notebook following the initial cell.
         All contents will be inserted using the ``MD.write()`` function.
 
         .. code-block:: python
@@ -513,10 +515,10 @@ class mdx:
             MD.write("... even more blah blah blah :::")
             MD.write("\\n\\n")
             md(MD.out())            # close the chapter file
-            
+
         **Chapter 2**
-        
-        This is the second chapter in the notebook following the initial cell. 
+
+        This is the second chapter in the notebook following the initial cell.
         All contents will be inserted using the ``MD.write()`` function.
 
         .. code-block:: python
@@ -528,10 +530,10 @@ class mdx:
             MD.write("... even more blah blah blah :::")
             MD.write("\\n\\n")
             md(MD.out())            # close the chapter file
-            
+
         **Chapter 3**
-        
-        This is the third chapter in the notebook following the initial cell. 
+
+        This is the third chapter in the notebook following the initial cell.
         All contents will be inserted using the ``MD.write()`` function.
 
         .. code-block:: python
@@ -543,14 +545,14 @@ class mdx:
             MD.write("... even more blah blah blah :::")
             MD.write("\\n\\n")
             md(MD.out())            # close the chapter file
-            
-        One can have an arbitrary number of chapters.  It is preferred to 
+
+        One can have an arbitrary number of chapters.  It is preferred to
         complete with one last segment on references:
 
         **The last content cell that contains the bibliography (optional)**
-        
+
         ::
-        
+
             SECTION=len(TOC)
             MD=mdx(Chapter, SECTION, TOC[SECTION-1])
             MD.write("Robert L. Mott, MECH2100 Machine Design (Custom Edition)\\n\\n")
@@ -558,8 +560,8 @@ class mdx:
             (Electronic resource, Call Number:TA403.6 .A74 2011eb )\\n\\n")
             MD.write("Standards Australia, 1993.  Engineering Drawing Handbook SAA HB7, Standards Association of Australia, (Call Number:T357 .M43 1993 )\\n\\n")
             md(MD.out())
-            
-        Read the following information on the `` write()`` method to see how you can 
+
+        Read the following information on the `` write()`` method to see how you can
         generate cells with interesting content.
 
     """
@@ -676,88 +678,88 @@ class mdx:
         self.Fdx.close()
 
     def write(self, s):
-        """ 
+        """
             This is the main method to populate the MDX notebook cells.  Apart
-            from the code segments, the string ``s`` is copied to the markdown 
+            from the code segments, the string ``s`` is copied to the markdown
             file.  The code segments start with ``:::`` and end with ``::``
 
             They are of the following format:
-                
+
                 ``:::code|arg1|arg2::``
-                    
+
             where
-            
+
                 ``code`` a number that defines the action
-                
+
                 ``arg1`` the first argument
-                
+
                 ``arg2`` the second argument
-                
+
             The following lists what is available through this construct:
-                
+
             **:::2**
-                
-            ``:::2|HTML link|text::``  The markdown document will display 
+
+            ``:::2|HTML link|text::``  The markdown document will display
             ``text`` that will link to the address defined in the first argument
-            
+
             *Code 2 Example:*
-            
+
                 ``:::2|www.uq.edu.au|University of Queensland::``
-                
+
             **:::3**
-            
-            ``:::3|filename|caption::`` will display the image in the first 
+
+            ``:::3|filename|caption::`` will display the image in the first
             argument.
-            
+
             The image file is expected to be in the ``pics`` folder.
-            
-            The figure numbers are automatically incremented.  The 
-            second argument is optional.  If omitted, then only the figure number 
+
+            The figure numbers are automatically incremented.  The
+            second argument is optional.  If omitted, then only the figure number
             will be shown:
-                
+
             *Code 3 Examples*
-            
+
             ``:::3|mohrcircle.png|Mohr's circle::``  # with caption text
             ``:::3|mohrcircle.png::``                # no caption
 
             **:::30**
-            
+
             Similar to **:::3** except that the image file is expected to be in the ``tmp`` folder.
 
             **:::32**
-            
-            Similar to **:::3** except that the image file is expected to be in the ``..\\pics`` folder. 
+
+            Similar to **:::3** except that the image file is expected to be in the ``..\\pics`` folder.
             This is useful when several notebooks use the same picture collection in the parent folder.
-                            
+
             **:::4**
-            
-            ``:::4|filename|cover text::`` the cover text will be a link to a pop-up window 
-            
+
+            ``:::4|filename|cover text::`` the cover text will be a link to a pop-up window
+
             The image file is expected to be in the ``pics`` folder.
 
             *Code 4 Examples*
-            
+
             ``:::4|mohrcircle.png|Click to see Mohr's circle::``  # pop=up figure.  The second argument is the cover text.
 
             **:::42**
-            
-            Similar to **:::4** except that the image file is expected to be in the ``..\\pics`` folder. 
+
+            Similar to **:::4** except that the image file is expected to be in the ``..\\pics`` folder.
             This is useful when several notebooks use the same picture collection in the parent folder.
-                            
+
             **:::5**
-            
-            ``:::5|equation|equation name::`` The equation name can later be used to refer to this equation by number 
+
+            ``:::5|equation|equation name::`` The equation name can later be used to refer to this equation by number
             by using the ``eqnumber()`` function or :::6 command.  The equation name may be left out.
 
             *Code 5 Examples*
-            
+
             ``:::5|$sin^2(x)+cos^2(x)=1$|trig::``
 
             ``:::5|F=ma|Newton::``
 
             ``:::5|$y=x^2$::``
 
-                            
+
         """
         self.Fdx = open(self.OutputFile, "a")
         tokens = s.split("::")
@@ -796,7 +798,9 @@ class mdx:
                 elif fnum == 4 or fnum == 42:  # image pop up (pics folder)
                     if fnum == 4:
                         sf = imgref("pics/%s" % a[1], a[2])
-                        mdxziplist(["pics"+chr(92)+a[1]])  # chr(92)="\\"
+                        filetozip="pics"+chr(92)+a[1]    # chr(92)="\\"
+                        filetozip=ff2p("pics", a[1])
+                        mdxziplist([filetozip])
                     # show image from ../pics folder (used in the pages)
                     elif fnum == 42:
                         sf = imgref("../pics/%s" % a[1], a[2])
@@ -1329,4 +1333,4 @@ def sapp(p, s):
         i += 1
 
 def xtver():
-    return "4:04 pm 20 July 2021"
\ No newline at end of file
+    return "4:04 pm 20 July 2021"
